/* vi: ts=8 sts=4 sw=4
 *
 * This file is part of the KDE project, module kdesu.
 * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
 *
 * This is free software; you can use this library under the GNU Library
 * General Public License, version 2. See the file "COPYING.LIB" for the
 * exact licensing terms.
 */

#ifndef __Defaults_h_included__
#define __Defaults_h_included__

namespace KDESu {

const int defTimeout = 120*60;
const int defEchoMode = 0;
const bool defKeep = false;

}

#endif
